#include "widget.h"
#include "ui_widget.h"
#include <QDebug>
#include <QNetworkConfigurationManager>


Widget::Widget(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::Widget),
    m_reply(0)
{
    ui->setupUi(this);
    m_networkAccessManager = new QNetworkAccessManager(this);
}

void Widget::on_pushButton_clicked()
{
    QNetworkConfigurationManager networkConfManager;
    if (!networkConfManager.isOnline()) {
        qDebug("Network is offline!");
        return;
    }

    ui->label->setText(QString());
    QNetworkRequest request(QUrl("http://www.example.com"));
    m_reply = m_networkAccessManager->get(request);
    Q_ASSERT(m_reply);
    connect(m_reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(networkReplay_error(QNetworkReply::NetworkError)));
    connect(m_reply, SIGNAL(finished()), this, SLOT(networkReplay_finished()));
    qDebug("Network request has been sent!");
}

void Widget::networkReplay_error(QNetworkReply::NetworkError code)
{
    qDebug() << "network error!, code=" << code;
}

void Widget::networkReplay_finished()
{
    if (m_reply->error() == QNetworkReply::NoError) {
        qDebug("Network request finished!");
        ui->label->setText(QString::fromUtf8(m_reply->readAll()));
    } else {
        qDebug() << "Network request finished with error!, code=" << m_reply->error();
    }
}

Widget::~Widget()
{
    delete ui;
}
